==> haskell-tasty-silver-3.3.2-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-silver.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-silver
version:              3.3.2
visibility:           public
id:                   tasty-silver-3.3.2-CIwBNVlQlkI4Fx8sx4hHFl
key:                  tasty-silver-3.3.2-CIwBNVlQlkI4Fx8sx4hHFl
license:              MIT
maintainer:           Andreas Abel, Philipp Hausmann
author:               Philipp Hausmann, Andreas Abel, Roman Cheplyaka, and others
homepage:             https://github.com/phile314/tasty-silver
synopsis:             A fancy test runner, including support for golden tests.
description:
    This package provides a fancy test runner and support for «golden testing».

    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.

    The test runner allows filtering tests using regexes, and to interactively
    inspect the result of golden tests.

    This package is a heavily extended fork of tasty-golden.

category:             Testing
abi:                  fb02b4179901e33c49d6a6cd6d993e6a
exposed:              True
exposed-modules:
    Test.Tasty.Silver Test.Tasty.Silver.Advanced
    Test.Tasty.Silver.Filter Test.Tasty.Silver.Interactive
    Test.Tasty.Silver.Interactive.Run Test.Tasty.Silver.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-silver-3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-silver-3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-silver-3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-silver
hs-libraries:         HStasty-silver-3.3.2-CIwBNVlQlkI4Fx8sx4hHFl
depends:
    ansi-terminal-1.0.2-FkjFmzyZyQ09kjMl1I4g29
    async-2.2.5-LqkzH7L8HyYHud0cQFVYjz base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    optparse-applicative-0.18.1.0-LtQWPLKmjlx59fIGxpWSti
    process-1.6.18.0 process-extras-0.7.4-62NRsgNkWsT7lcfVwPv1jR
    regex-tdfa-1.3.2.4-F7fHSRmw2rGDNk5aODvyIV
    silently-1.2.5.4-9u7UVppGqLDJYp1Db2hbZU stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-CTbHF7UXRKc7HYc3AMspUq
    temporary-1.3-9rtP6hocReL6fK4gSjxIEA text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-tasty-silver/html/tasty-silver.haddock

haddock-html:         /usr/share/doc/haskell-tasty-silver/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-silver-3.3.2-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-silver.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-silver
version:              3.3.2
visibility:           public
id:                   tasty-silver-3.3.2-5on0VmqkcWY4rVd1VFJJfl
key:                  tasty-silver-3.3.2-5on0VmqkcWY4rVd1VFJJfl
license:              MIT
maintainer:           Andreas Abel, Philipp Hausmann
author:               Philipp Hausmann, Andreas Abel, Roman Cheplyaka, and others
homepage:             https://github.com/phile314/tasty-silver
synopsis:             A fancy test runner, including support for golden tests.
description:
    This package provides a fancy test runner and support for «golden testing».

    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.

    The test runner allows filtering tests using regexes, and to interactively
    inspect the result of golden tests.

    This package is a heavily extended fork of tasty-golden.

category:             Testing
abi:                  0cfa42210093af48edbd26aca5e25357
exposed:              True
exposed-modules:
    Test.Tasty.Silver Test.Tasty.Silver.Advanced
    Test.Tasty.Silver.Filter Test.Tasty.Silver.Interactive
    Test.Tasty.Silver.Interactive.Run Test.Tasty.Silver.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-silver-3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-silver-3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-silver-3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-silver
hs-libraries:         HStasty-silver-3.3.2-5on0VmqkcWY4rVd1VFJJfl
depends:
    ansi-terminal-1.0.2-FkjFmzyZyQ09kjMl1I4g29
    async-2.2.5-LqkzH7L8HyYHud0cQFVYjz base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    optparse-applicative-0.18.1.0-LtQWPLKmjlx59fIGxpWSti
    process-1.6.18.0 process-extras-0.7.4-Ecseddz1njuFCUZ8vRZI0c
    regex-tdfa-1.3.2.4-F7fHSRmw2rGDNk5aODvyIV
    silently-1.2.5.4-9u7UVppGqLDJYp1Db2hbZU stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-CTbHF7UXRKc7HYc3AMspUq
    temporary-1.3-9rtP6hocReL6fK4gSjxIEA text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-tasty-silver/html/tasty-silver.haddock

haddock-html:         /usr/share/doc/haskell-tasty-silver/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
